@@ -4,12 +4,13 @@ const editor = require('.');
   const answer = await editor({
     message: 'Please write a short bio of at least 3 lines.',
     validate(text) {
-      if (text.split('\n').length < 3) {
+      if (text.trim().split('\n').length < 3) {
         return 'Must be at least 3 lines.';
       }
 
       return true;
     },
   });
-  console.log('Answer:', answer);
+  console.log('Answer:');
+  console.log(answer);
 })();
